
% Clear workspace
clear all, close all, clc
format compact

% Load workspace from calibration
load('calibration_20140507_231537');

% Open serial port
com = serial(com_port, 'BaudRate', 460800,'InputBufferSize',10000);
fopen(com);

% Open binary file for saving inertial data
file = fopen('imu_data.bin', 'w');

% Tell the module to output raw measurement data
fwrite(com,command,'uint8');
fread(com,4,'uint8')

% Open dummy figure with pushbutton such that logging can be aborted
abort = 0;
figure(3);
uicontrol('style','push','string','Abort data logging','callback','abort=1;');
drawnow

% % Logg data until pushbutton pressed
while abort==0
    if com.BytesAvailable>0
        fwrite(file,fread(com,com.BytesAvailable,'uint8'),'uint8');
    end
    drawnow
end

% Stop output
fwrite(com,[33 0 33],'uint8');

% Close serial port and file
fclose(com);
fclose(file);
close(3);

% Parse data
if strcmp(wireless,'no')
    inertial_data_raw=matlab_parse_bin('imu_data.bin',uint8(nr_imus));
elseif strcmp(wireless,'yes')
    inertial_data_raw=matlab_parse_wireless('imu_data.bin',uint8(nr_imus));
else
    disp('unknown value of wireless');
    break;
end
inertial_data_test=double(inertial_data_raw);

%% Compensate and plot data

figure(1),clf, hold on
for i=0:nr_imus-1
    R = reshape(C_nom(i+1,1:9),3,3)';
    data = R*inertial_data_test(i*6+(1:3),:);
    plot(data(1,:)'*scale_acc,'b-')
    plot(data(2,:)'*scale_acc,'g-')
    plot(data(3,:)'*scale_acc,'r-')
    R = reshape(double(C_int(i+1,1:9)),3,3)';
    data = R*inertial_data_test(i*6+(1:3),:)*nr_imus/2^(floor(log2(nr_imus)))*scale_acc/calib_gain - repmat(theta(i+1,4:6)',1,size(inertial_data_test,2));
    plot(data(1,:),'c-')
    plot(data(2,:),'m-')
    plot(data(3,:),'y-')
    plot(sqrt(sum(data.^2,1)),'b-');
end
grid on
title('Accelerometer readings');
xlabel('sample number')
ylabel('a [m/s^2]');
figure(2),clf, hold on
for i=0:nr_imus-1
    R = reshape(C_nom(i+1,1:9),3,3)';
    data = R*inertial_data_test(i*6+(4:6),:);
    plot(data(1,:)'*scale_gyro,'b-')
    plot(data(2,:)'*scale_gyro,'g-')
    plot(data(3,:)'*scale_gyro,'r-')
    R = reshape(double(C_int(i+1,10:18)),3,3)';
    data = R*inertial_data_test(i*6+(4:6),:)*nr_imus/2^(floor(log2(nr_imus)))*scale_gyro/calib_gain - repmat(theta(i+1,10:12)',1,size(inertial_data_test,2));
    plot(data(1,:),'c-')
    plot(data(2,:),'m-')
    plot(data(3,:),'y-')
end
grid on
title('Gyroscope readings');
xlabel('sample number')
ylabel('\omega [deg/s]');

%% Fuse and plot data

inertial_data_comp = int32(zeros(6,size(inertial_data_raw,2)));
for i=1:size(inertial_data_raw,2)
    for m=1:nr_imus
        u_tmp = int32(zeros(6,1));
        for j=1:3
            % Integer
            u_tmp(j) = u_tmp(j) + C_int(m,(j-1)*3+1) * int32(inertial_data_raw(6*(m-1)+1,i));
            u_tmp(j) = u_tmp(j) + C_int(m,(j-1)*3+2) * int32(inertial_data_raw(6*(m-1)+2,i));
            u_tmp(j) = u_tmp(j) + C_int(m,(j-1)*3+3) * int32(inertial_data_raw(6*(m-1)+3,i));

            u_tmp(j+3) = u_tmp(j+3) + C_int(m,(j-1)*3+10) * int32(inertial_data_raw(6*(m-1)+4,i));
            u_tmp(j+3) = u_tmp(j+3) + C_int(m,(j-1)*3+11) * int32(inertial_data_raw(6*(m-1)+5,i));
            u_tmp(j+3) = u_tmp(j+3) + C_int(m,(j-1)*3+12) * int32(inertial_data_raw(6*(m-1)+6,i));
        end
        % This division (shift) will cause an insignificant bias
        u_tmp = idivide(u_tmp,2^(floor(log2(nr_imus))),'floor');
        inertial_data_comp(:,i) = inertial_data_comp(:,i) + u_tmp;
    end
    inertial_data_comp(1:3,i) = inertial_data_comp(1:3,i) - b_acc_int;
    inertial_data_comp(4:6,i) = inertial_data_comp(4:6,i) - b_gyro_int;
end
figure(1)
plot(double(inertial_data_comp(1,:))/calib_gain*scale_acc,'k-')
plot(double(inertial_data_comp(2,:))/calib_gain*scale_acc,'k-')
plot(double(inertial_data_comp(3,:))/calib_gain*scale_acc,'k-')
plot(sqrt(double(inertial_data_comp(1,:)).^2+double(inertial_data_comp(2,:)).^2+double(inertial_data_comp(3,:)).^2)/calib_gain*scale_acc,'k--','LineWidth',2);

figure(2)
plot(double(inertial_data_comp(4,:))/calib_gain*scale_gyro,'k-')
plot(double(inertial_data_comp(5,:))/calib_gain*scale_gyro,'k-')
plot(double(inertial_data_comp(6,:))/calib_gain*scale_gyro,'k-')
