function z=Costfunction(theta)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%>                                                                         
%>  Cost function used in the calibration of the IMU array. Note that
%>  the nonlinear least square optimizer in Matlab requires the cost
%>  function to return the individual errors and note the squared sume of
%>  the errors. 
%>  
%>  Output:     z       A 3*L element long vector with all the individual errors    
%>  Input:      theta   A 6 element long vector with the optimization
%>                      parameters
%>
%>  @authors Isaac Skog, John-Olof Nilsson
%>  @copyright Copyright (c) 2013 OpenShoe, ISC License (open source)
%>
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



global y;
global Qinv;
global g_local;

[~,L]=size(y);

z=zeros(3,L);





for l=1:L
    
    % Estimate the roll and pitch at the l:th orientation and construct the 
    % input vector u^(i)_n.
    roll=theta(2*(l-1)+1);
    pitch=theta(2*(l-1)+2);
    u=g_local*[ -sin(pitch) cos(pitch)*sin(roll) cos(pitch)*cos(roll)]';
    
    % Calculate the difference between the estimated and measured output of
    % the M IMUs. 
    
    
    K=diag(theta(2*L+1:2*L+3));
    b=theta(2*L+4:2*L+6);
    
    y_hat=K*u+b;
    
    z(:,l)=squeeze(Qinv(:,:,l))*(y(:,l)-y_hat);   
end

z=reshape(z,3*L,1); 
end