
function MIMU_plot_calib(calib_meas,nr_imus,C_int,C_nom,theta,acc_scale,gyro_scale,calib_gain,b_acc_int,b_gyro_int,nr_sides)

% Prepare the figures
figure(2),clf, hold on
set(gcf,'WindowStyle','docked')
grid on
title('Accelerometer readings');
xlabel('sample number')
ylabel('a [m/s^2]');
figure(3),clf, hold on
set(gcf,'WindowStyle','docked')
grid on
title('Gyroscope readings');
xlabel('sample number')
ylabel('\omega [deg/s]');

% Loop over calibration data sets
start_plot = 0;
for data_set=1:nr_sides
    nr_data = size(calib_meas{data_set},2);
    
    inert_data = double(calib_meas{data_set});
    figure(2)
    for i=0:nr_imus-1
        R = reshape(C_nom(i+1,1:9),3,3)';
        data = R*inert_data(i*6+(1:3),:);
        plot(start_plot+(1:nr_data),data(1,:)*acc_scale,'b-')
        plot(start_plot+(1:nr_data),data(2,:)*acc_scale,'g-')
        plot(start_plot+(1:nr_data),data(3,:)*acc_scale,'r-')
        plot(start_plot+(1:nr_data),sqrt(sum((data(1:3,:)*acc_scale).^2,1)),'Color',rgb('DarkCyan'));
        R = reshape(double(C_int(i+1,1:9)),3,3)';
        data = R*inert_data(i*6+(1:3),:)*acc_scale/calib_gain - repmat(theta(i+1,4:6)',1,nr_data);
        plot(start_plot+(1:nr_data),data(1,:),'c-')
        plot(start_plot+(1:nr_data),data(2,:),'m-')
        plot(start_plot+(1:nr_data),data(3,:),'y-')
        plot(start_plot+(1:nr_data),sqrt(sum(data(1:3,:).^2,1)),'Color',rgb('Gold'));
    end
    figure(3)
    for i=0:nr_imus-1
        R = reshape(C_nom(i+1,1:9),3,3)';
        data = R*inert_data(i*6+(4:6),:);
        plot(start_plot+(1:nr_data),data(1,:)'*gyro_scale,'b-')
        plot(start_plot+(1:nr_data),data(2,:)'*gyro_scale,'g-')
        plot(start_plot+(1:nr_data),data(3,:)'*gyro_scale,'r-')
        R = reshape(double(C_int(i+1,10:18)),3,3)';
        data = R*inert_data(i*6+(4:6),:)*gyro_scale/calib_gain - repmat(theta(i+1,10:12)',1,nr_data);
        plot(start_plot+(1:nr_data),data(1,:),'c-')
        plot(start_plot+(1:nr_data),data(2,:),'m-')
        plot(start_plot+(1:nr_data),data(3,:),'y-')
    end
    
    inertial_data_comp = int32(zeros(6,nr_data));
    for i=1:nr_data
        for m=1:nr_imus
            u_tmp = int32(zeros(6,1));
            for j=1:3
                % Integer
                u_tmp(j) = u_tmp(j) + C_int(m,(j-1)*3+1) * int32(calib_meas{data_set}(6*(m-1)+1,i));
                u_tmp(j) = u_tmp(j) + C_int(m,(j-1)*3+2) * int32(calib_meas{data_set}(6*(m-1)+2,i));
                u_tmp(j) = u_tmp(j) + C_int(m,(j-1)*3+3) * int32(calib_meas{data_set}(6*(m-1)+3,i));
                
                u_tmp(j+3) = u_tmp(j+3) + C_int(m,(j-1)*3+10) * int32(calib_meas{data_set}(6*(m-1)+4,i));
                u_tmp(j+3) = u_tmp(j+3) + C_int(m,(j-1)*3+11) * int32(calib_meas{data_set}(6*(m-1)+5,i));
                u_tmp(j+3) = u_tmp(j+3) + C_int(m,(j-1)*3+12) * int32(calib_meas{data_set}(6*(m-1)+6,i));
            end
            % This division (shift) will cause an insignificant bias
            u_tmp = idivide(u_tmp,2^(floor(log2(nr_imus))),'floor');
            inertial_data_comp(:,i) = inertial_data_comp(:,i) + u_tmp;
        end
        inertial_data_comp(1:3,i) = inertial_data_comp(1:3,i) - b_acc_int;
        inertial_data_comp(4:6,i) = inertial_data_comp(4:6,i) - b_gyro_int;
    end
    figure(2)
    plot(start_plot+(1:nr_data),double(inertial_data_comp(1,:))/calib_gain*acc_scale,'k-')
    plot(start_plot+(1:nr_data),double(inertial_data_comp(2,:))/calib_gain*acc_scale,'k-')
    plot(start_plot+(1:nr_data),double(inertial_data_comp(3,:))/calib_gain*acc_scale,'k-')
    plot(start_plot+(1:nr_data),sqrt(double(inertial_data_comp(1,:)).^2+double(inertial_data_comp(2,:)).^2+double(inertial_data_comp(3,:)).^2)/calib_gain*acc_scale,'k--','LineWidth',2);
    
    figure(3)
    plot(start_plot+(1:nr_data),double(inertial_data_comp(4,:))/calib_gain*gyro_scale,'k-')
    plot(start_plot+(1:nr_data),double(inertial_data_comp(5,:))/calib_gain*gyro_scale,'k-')
    plot(start_plot+(1:nr_data),double(inertial_data_comp(6,:))/calib_gain*gyro_scale,'k-')
    
    start_plot = start_plot + nr_data;
end

figure(1)

end