
function  [C_int,b_acc_int,b_gyro_int] = calibration_matrix(theta,theta_acc_scale,theta_gyro_scale,C_nom,calib_gain)

nr_imus = size(theta,1);

k = theta(:,1:3); % No units
b_acc = theta(:,4:6)*theta_acc_scale;  % In bits
s = theta(:,7:9); % In radians
e = theta(:,10:12);  % In radians
b_gyro = theta(:,13:15)*theta_gyro_scale;  % In bits

C = zeros(32,18);

% Loop over IMUs
for m = 1:nr_imus
    R = reshape(C_nom(m,1:9),3,3);
    K = diag(k(m,:));
    S = [1 -s(m,1) s(m,2);
         0  1     -s(m,3);
         0  0      1];
    E = [1       e(m,3) -e(m,2);
        -e(m,3)  1       e(m,1);
         e(m,2) -e(m,1)  1     ];
    tmp = inv(K*S*E);
    tmp2 = tmp*R;
    tmp3 = inv(E);
    tmp4 = tmp3*R;
    C(m,1:9) = tmp2(:);
    C(m,10:18) = tmp4(:);
    b_acc(m,:) = (tmp*b_acc(m,:)')';
    b_gyro(m,:) = (tmp3*b_gyro(m,:)')';
end
C = C/nr_imus;
C_int = int32(round(C*calib_gain*2^floor(log2(nr_imus)) ));
b_acc_int = int32(round(sum(b_acc*calib_gain/nr_imus)))';
b_gyro_int = int32(round(sum(b_gyro*calib_gain/nr_imus)))';
